#!/usr/bin/env python
#
# Copyright (C) 2010, 2011, 2012, 2013, 2014 Intel, Inc.
#
#    This program is free software; you can redistribute it and/or
#    modify it under the terms of the GNU General Public License
#    as published by the Free Software Foundation; version 2
#    of the License.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
"""This script is used to update infomation about images"""

import os
import sys
import base64
import datetime

from common.buildtrigger import trigger_info, trigger_next
from common.buildservice import BuildService
from common.prerelease import is_prerelease_project
from common.iris_rest_client import IrisRestClient

def main():
    """The main body"""
    buildmonitor_enabled = os.getenv("BUILDMONITOR_ENABLED", "0") != "0"
    print 'buildmonitor_enabled(%s)\n' % (buildmonitor_enabled)
    if buildmonitor_enabled:
        bm_start_datetime = datetime.datetime.now()

    obs_api = os.getenv("OBS_API_URL")
    obs_user = os.getenv("OBS_API_USERNAME")
    obs_passwd = os.getenv("OBS_API_PASSWD")

    content = trigger_info(os.getenv('TRIGGER_INFO'))

    project = content.get('project', '')
    name = content.get('name')
    status = content.get('status', '')
    url = content.get('url', '')
    build_id = content.get('build_id', '')
    # add image_created log for iris
    pub_enabled = os.getenv("IRIS_PUB_ENABLED", "0") != "0"
    if pub_enabled:
        rest = IrisRestClient(
            os.getenv("IRIS_SERVER"),
            os.getenv("IRIS_USERNAME"),
            base64.b64decode(os.getenv('IRIS_PASSWORDX', '')))
        rest.publish_event("image_created", {
        "project": project,
        "status": status,
        "name": name,
        "url": url,
        })

    # If the project is prerelease project, trigger the post-image-creation
    if is_prerelease_project(project):
        build = BuildService(obs_api, obs_user, obs_passwd)

        saveinfo = build.get_info(project)
        if saveinfo.get('download_num', 0) != content.get('download_num', 1):
            print 'EXCEPTION* mismatch download_num current:%s, obs:%s' \
                  % (content.get('download_num'), saveinfo.get('download_num'))
            print 'SKIP UPDATING BUILD INFO'
            return

        info = {"images":
                    [{"name": name,
                     "status": status,
                     "url": url}]
                }
        build.update_info(info, project)

        if buildmonitor_enabled:
            saveinfo = build.get_info(project)
            if len(saveinfo['images']) == saveinfo['images_count']:
                print '[%s] last image(%s)\n' \
                      % (__file__, len(saveinfo['images']))
                #buildmonitor.end_create_image_for_sr_stage(bm_start_datetime,
                #                                           project)
                bm_stage = 'Post_Image'
                bm_data = {"bm_stage" : bm_stage,
                           "bm_start_datetime" : str(bm_start_datetime),
                           "project" : project,
                           "bm_snapshot_name" : build_id,
                          }
                trigger_next("BUILD-MONITOR", bm_data)

if __name__ == "__main__":
    sys.exit(main())
